@@ -221,20 +221,20 @@ CameraExtension = Literal[
     "intercom",
 ]
 
+Point = tuple[int, int]
 
-class CameraZone(TypedDict):
+ZoneType = Literal["intersect", "contain"]
+
+ZoneFilter = Literal["include", "exclude"]
+
+
+class DetectionZone(TypedDict):
     name: str
-    regions: list["ZoneRegion"]
-
-
-class ZoneRegion(TypedDict):
-    _id: str
-    coords: list["ZoneCoord"]
-
-
-class ZoneCoord(TypedDict):
-    _id: str
-    points: tuple[int, int]
+    points: list[Point]
+    type: ZoneType
+    filter: ZoneFilter
+    classes: list[str]
+    isPrivacyMask: bool
 
 
 class CameraInformation(TypedDict):
@@ -246,10 +246,22 @@ class CameraInformation(TypedDict):
     supportUrl: str
 
 
+class MotionDetectionSettings(TypedDict):
+    timeout: int
+
+
+class ObjectDetectionSettings(TypedDict): ...
+
+
+class CameraActivitySettings(TypedDict):
+    motion: MotionDetectionSettings
+    object: ObjectDetectionSettings
+
+
 CameraType = Literal["camera", "doorbell"]
 
 
-class BaseCamera(TypedDict):
+class Camera(TypedDict):
     _id: str
     nativeId: NotRequired[str]
     pluginId: str
@@ -262,11 +274,8 @@ class BaseCamera(TypedDict):
     hasBattery: bool
     info: CameraInformation
     type: CameraType
-    motionZones: list[CameraZone]
-    objectZones: list[CameraZone]
-
-
-class Camera(BaseCamera):
+    activityZones: list[DetectionZone]
+    activitySettings: CameraActivitySettings
     hasAudioDetector: bool
     hasMotionDetector: bool
     hasObjectDetector: bool
@@ -286,8 +295,8 @@ CameraPublicProperties = Literal[
     "hasBattery",
     "info",
     "type",
-    "motionZones",
-    "objectZones",
+    "activityZones",
+    "activitySettings",
     "hasAudioDetector",
     "hasMotionDetector",
     "hasObjectDetector",
@@ -302,13 +311,14 @@ PropertyValue = Union[
     bool,
     CameraInformation,
     CameraType,
-    list[CameraZone],
+    CameraActivitySettings,
+    list[DetectionZone],
     list[CameraInput],
 ]
 
 
 # camera device
-class BaseDetection(TypedDict):
+class Detection(TypedDict):
     id: NotRequired[str]
     label: str
     confidence: float
@@ -319,12 +329,6 @@ class BaseDetection(TypedDict):
     origHeight: int
 
 
-class MotionDetection(BaseDetection): ...
-
-
-class ObjectDetection(BaseDetection): ...
-
-
 class BaseStateLight(TypedDict):
     timestamp: str
     lastEvent: NotRequired[Optional["LightStateWithoutLastEvent"]]
@@ -365,8 +369,8 @@ class BaseStateWithoutLastEvent(TypedDict):
 
 
 class MotionSetEvent(TypedDict):
-    state: bool
-    detections: list[MotionDetection]
+    state: NotRequired[bool]
+    detections: list[Detection]
 
 
 class AudioSetEvent(TypedDict):
@@ -375,7 +379,7 @@ class AudioSetEvent(TypedDict):
 
 
 class ObjectSetEvent(TypedDict):
-    detections: list[ObjectDetection]
+    detections: list[Detection]
 
 
 class LightSetEvent(TypedDict):
@@ -624,6 +628,22 @@ class FrameMetadata(TypedDict):
     origHeight: int
 
 
+class ImageInformation(TypedDict):
+    width: int
+    height: int
+    channels: int
+
+
+class FrameBuffer(TypedDict):
+    image: bytes
+    info: ImageInformation
+
+
+class FrameImage(TypedDict):
+    image: Image.Image
+    info: ImageInformation
+
+
 class VideoFrame(Protocol):
     @property
     def metadata(self) -> FrameMetadata: ...
@@ -633,8 +653,8 @@ class VideoFrame(Protocol):
     def input_height(self) -> int: ...
     @property
     def input_format(self) -> str: ...
-    async def to_buffer(self, options: Optional[ImageOptions] = None) -> bytes: ...
-    async def to_image(self, options: Optional[ImageOptions] = None) -> Image.Image: ...
+    async def to_buffer(self, options: Optional[ImageOptions] = None) -> FrameBuffer: ...
+    async def to_image(self, options: Optional[ImageOptions] = None) -> FrameImage: ...
 
 
 SV = TypeVar("SV", bound=StateValue)
@@ -661,8 +681,8 @@ class CameraDevice(Protocol):
     type: CameraType
     info: CameraInformation
     sources: list[CameraSource]
-    motion_zones: list[CameraZone]
-    object_zones: list[CameraZone]
+    activity_zones: list[DetectionZone]
+    activity_settings: CameraActivitySettings
     is_cloud: bool
     has_light: bool
     has_siren: bool
@@ -825,8 +845,12 @@ class CameraDevice(Protocol):
     ) -> Observable[CameraPropertyObservableObject[CameraType]]: ...
     @overload
     def on_property_change(
-        self, property_name: Literal["motionZones", "objectZones"]
-    ) -> Observable[CameraPropertyObservableObject[list[CameraZone]]]: ...
+        self, property_name: Literal["activityZones"]
+    ) -> Observable[CameraPropertyObservableObject[list[DetectionZone]]]: ...
+    @overload
+    def on_property_change(
+        self, property_name: Literal["activitySettings"]
+    ) -> Observable[CameraPropertyObservableObject[CameraActivitySettings]]: ...
     @overload
     def on_property_change(
         self, property_name: Literal["sources"]
@@ -878,14 +902,9 @@ CameraDeselectedCallback = Union[
     Callable[[str, CameraExtension], None],
     Callable[[str, CameraExtension], Coroutine[None, None, None]],
 ]
-CameraAddedCallback = Union[
-    Callable[[CameraDevice], None],
-    Callable[[CameraDevice], Coroutine[None, None, None]],
-]
-CameraRemovedCallback = Union[Callable[[str], None], Callable[[str], Coroutine[None, None, None]]]
 CameraUpdatedCallback = Union[
-    Callable[[str, CameraDevice], None],
-    Callable[[str, CameraDevice], Coroutine[None, None, None]],
+    Callable[[str, CameraExtension], None],
+    Callable[[str, CameraExtension], Coroutine[None, None, None]],
 ]
 
 
